.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary_hpc.executor:

executor
========

.. automodule:: canary_hpc.executor
   :members:
   :undoc-members:
   :show-inheritance:
